@@ -81,13 +81,19 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="0"/>
-        <source>Folder </source>
+        <source>Theme </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="0"/>
-        <source> already exists!</source>
+        <source> already exists and cannot be overwritten!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Overwrite existing theme?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Theme with this name already exists, do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
